pro tr_rd_index, sttim0, entim0, index, files, map, $
		offset_time=offset_time, type=type, $
		qstop=qstop, struct=struct, qdebug=qdebug, $
		notrim=notrim
;+
;NAME:
;	tr_rd_index
;PURPOSE:
;	To read the TRACE Raw Image (tri) index (binary tables)
;SAMPLE CALLING SEQUENCE:
;	tr_rd_index, sttim, entim, index, files, map
;	tr_rd_index, '18-Feb-98', '18-Feb-98 2:00', index
;	tr_rd_index, '4-Dec-97', '4-Dec-97 6:00', index, offset=6558102D
;INPUT:
;	sttim	- Start date/time
;	entim	- End date/time
;OUTPUT:
;	index	- Index header structure
;	files	- Source files
;	map	- Structure to allow quick access back into the files
;OPTIONAL KEYWORD INPUT:
;	type	- Type of file (tri, trm, trj).  Default is tri
;	offset_time-Offset to add to the input time to get from real
;		GMT time to S/C time
;			Test			Offset
;			-----			------
;			Aug-97 TV Tran#1	10755718
;			Sep-97 TV Tran#2	10876652
;			Sep-97 TV Tran#3	10681753
;			Sep-97 TV 3Day Contam	10599526
;			Oct-97 Sim		5883452
;			Nov-97 Sim		8983857
;			Dec-97 Sim		6558102
;	notrim	- Don't do time selection after reading
;HISTORY:
;	Written 4-Dec-97 by M.Morrison
;	11-Dec-97 (MDM) - Patch to avoid "tril" files (list files)
;	30-Jan-98 (MDM) - Added /STRUCT option to convert the index
;			  to tag names
;	25-Mar-98 (MDM) - "Zero" out the index structure if no data
;			  for the time span requested
;	 9-Apr-98 (MDM) - Added /QDEBUG
;	20-Apr-98 (RAS) - cleared inputs through ANYTIM for safety and removed 
;			  null strings from all_dirs and all_ff after file_list().
;	21-Apr-98 (DMZ) - added some input error checking
;-
;

if (not exist(entim0)) or (not exist(sttim0)) then begin
 message,'Syntax --> tr_rd_index, sttim, entim, index, files, map',/cont
 return
endif

sttim = anytim(sttim0,/ints)		;user input times (real GMT)
entim = anytim(entim0,/ints)
if (keyword_set(offset_time)) then begin
    sttim = anytim2ints(sttim0, off=offset_time)	;S/C times
    entim = anytim2ints(entim0, off=offset_time)
end
;
if (n_elements(type) eq 0) then type = 'tri'
;
base_dirs = str2arr( getenv('TRACE_I1_DIR') )
all_dirs = file_list(base_dirs, 'week*')	;dir per day
w = where(all_dirs ne '', nw)
if nw gt 0 then all_dirs=all_dirs(w)
if (keyword_set(qdebug)) then prstr, all_dirs
if (all_dirs(0) eq '') then begin
    print, 'TR_RD_INDEX: No data dirs found in: ' + base_dirs + '  Returning...
    return
end
dirs = sel_filetimes(sttim, entim, all_dirs, /one_before, append='_0000')
if (keyword_set(qdebug)) then prstr, dirs
if (dirs(0) eq '') then begin
    print, 'TR_RD_INDEX: No data dirs for time range found.  
    print, 'TR_RD_INDEX: Timerange of ' + fmt_tim(sttim) + ' to ' + fmt_tim(entim)
    print, 'TR_RD_INDEX: Directories of: ', all_dirs
    print, 'TR_RD_INDEX: Returning...
    if (keyword_set(qstop)) then stop
    return
end
;
all_ff = file_list(dirs, type + '1*')
w = where(all_ff ne '', nw)
if nw gt 0 then all_ff=all_ff(w)
if (all_ff(0) eq '') then begin
    print, 'TR_RD_INDEX: No data files found in: ' + dirs + '  Returning...
    return
end
files = sel_filetimes(sttim, entim, all_ff, /one_before)
if (keyword_set(qdebug)) then prstr, files
if (files(0) eq '') then begin
    print, 'TR_RD_INDEX: No data files for time range found.  
    print, 'TR_RD_INDEX: Timerange of ' + fmt_tim(sttim) + ' to ' + fmt_tim(entim)
    print, 'TR_RD_INDEX: Data files: ', all_ff
    print, 'TR_RD_INDEX: Returning...
    return
end
;
mxf_read_header, files, index, map, /ext	;binary header
;
if (keyword_set(offset_time)) then begin	;look at .TIME and .DAY for times
    if (tag_exist(index, 'TIME')) then begin
	ss = sel_timrange(index, sttim0, entim0, /between)
    end else begin
	daytim = trace_dph2struct(ph, index, dph, taglist='img_time', /no_struct)
	ss = sel_timrange(daytim, sttim, entim, /between)
    end
end else begin
    qtrim = (not keyword_set(notrim))
    if (qtrim) then begin
	if (max(index.pkt_time) eq 0) then begin
	    daytim = trace_dph2struct(ph, index, dph, taglist='img_time', /no_struct)
	    ss = sel_timrange(daytim, sttim, entim, /between)
	end else begin
	    daytim = anytim2ints('24-May-68', off=double(index.pkt_time))
	    ss = sel_timrange(daytim, sttim, entim, /between)
	end
    end else begin
	ss = indgen(n_elements(index))	;all data
    end
end

if (ss(0) eq -1) then begin
    print, 'TR_RD_INDEX: No images for time range found.
    print, 'TR_RD_INDEX: Returning full hour sets 
    index = 0b		;MDM 25-Mar-98
    return
end
;
index = index(ss)
map = map(ss)
;
if (keyword_set(struct)) then index = trace_dph2struct(ph, index, taglist=taglist, head_db=db_file)

if (keyword_set(qstop)) then stop
end
